==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipo Kastro <fefcas@gmail.com>
 */
$lang['admin_acl']             = 'Administrado de Alirkontrola Listo (ACL)';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Uzulo';
$lang['acl_perms']             = 'Rajtoj por';
$lang['page']                  = 'Paĝo';
$lang['namespace']             = 'Nomspaco';
$lang['p_user_id']             = 'Uzulo <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Uzulo <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bonvole <b>enmeti uzulon aŭ grupon</b> en la suba agordilo por rigardi aŭ redakti la aron da rajtoj por la paĝo <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Bonvole <b>enmeti uzulon aŭ grupon</b> en la suba agordilo por rigardi aŭ redakti la aron da rajtoj por la nomspaco <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Rimarko: tiuj rajtoj ne estis rekte difinitaj, sed ili estis hereditaj el aliaj pli superaj grupoj aŭ nomspacoj.';
$lang['p_isadmin']             = 'Rimarko: la elektita grupo aŭ uzulo ĉiam havas plenan rajtaron ĉar ĝi estas difinita kiel superuzulo.';
$lang['current']               = 'Aktuala regularo ACL';
$lang['where']                 = 'Paĝo/Nomspaco';
$lang['who']                   = 'Uzulo/Grupo';
$lang['perm']                  = 'Rajtoj';
$lang['acl_perm0']             = 'Nenio';
$lang['acl_perm1']             = 'Legi';
$lang['acl_perm2']             = 'Redakti';
$lang['acl_perm4']             = 'Krei';
$lang['acl_perm8']             = 'Alŝuti';
$lang['acl_perm16']            = 'Forigi';
$lang['acl_new']               = 'Aldoni novan Enmetaĵon';
$lang['acl_mod']               = 'Modifi Enmetaĵon';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas@gmail.com>
 */
$lang['admin_acl']             = 'Administrado de Alirkontrola Listo (ACL)';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Uzanto';
$lang['acl_perms']             = 'Rajtoj por';
$lang['page']                  = 'Paĝo';
$lang['namespace']             = 'Nomspaco';
$lang['btn_select']            = 'Elekti';
$lang['p_user_id']             = 'Uzanto <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Uzanto <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Bonvole <b>enmeti uzulon aŭ grupon</b> en la suba agordilo por rigardi aŭ redakti la aron da rajtoj por la paĝo <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Bonvole <b>enmeti uzulon aŭ grupon</b> en la suba agordilo por rigardi aŭ redakti la aron da rajtoj por la nomspaco <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Rimarko: tiuj rajtoj ne estis rekte difinitaj, sed ili estis hereditaj el aliaj pli superaj grupoj aŭ nomspacoj.';
$lang['p_isadmin']             = 'Rimarko: la elektita grupo aŭ uzanto ĉiam havas plenan rajtaron ĉar ĝi estas difinita kiel superuzanto.';
$lang['p_include']             = 'Plialtaj permesoj inkluzivas malpli altajn. La permesoj por Krei, Alŝuti kaj Forigi nur aplikeblas al nomspacoj, ne al paĝoj.';
$lang['current']               = 'Aktuala regularo ACL';
$lang['where']                 = 'Paĝo/Nomspaco';
$lang['who']                   = 'Uzanto/Grupo';
$lang['perm']                  = 'Rajtoj';
$lang['acl_perm0']             = 'Nenio';
$lang['acl_perm1']             = 'Legi';
$lang['acl_perm2']             = 'Redakti';
$lang['acl_perm4']             = 'Krei';
$lang['acl_perm8']             = 'Alŝuti';
$lang['acl_perm16']            = 'Forigi';
$lang['acl_new']               = 'Aldoni novan Enmetaĵon';
$lang['acl_mod']               = 'Modifi Enmetaĵon';
